pub struct StandaloneKeywordAbility {
pub keyword_ability: StandaloneKeywordAbility,
}Expand description
Wrapper around the mtg type for the standalone keyword ability.
Fields
keyword_ability: StandaloneKeywordAbilityTrait Implementations
Sourceimpl AbilityTreeNode for StandaloneKeywordAbility
impl AbilityTreeNode for StandaloneKeywordAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for StandaloneKeywordAbility
impl Clone for StandaloneKeywordAbility
Sourcefn clone(&self) -> StandaloneKeywordAbility
fn clone(&self) -> StandaloneKeywordAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandaloneKeywordAbility
impl Debug for StandaloneKeywordAbility
Sourceimpl<'de> Deserialize<'de> for StandaloneKeywordAbility
impl<'de> Deserialize<'de> for StandaloneKeywordAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for StandaloneKeywordAbility
Available on crate feature parser only.
impl DummyInit for StandaloneKeywordAbility
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl Idris for StandaloneKeywordAbility
impl Idris for StandaloneKeywordAbility
Sourceimpl PartialEq for StandaloneKeywordAbility
impl PartialEq for StandaloneKeywordAbility
Sourceimpl Serialize for StandaloneKeywordAbility
impl Serialize for StandaloneKeywordAbility
impl Eq for StandaloneKeywordAbility
impl StructuralPartialEq for StandaloneKeywordAbility