pub struct WardKeywordAbility {
pub cost: Cost,
}Fields
cost: CostTrait Implementations
Sourceimpl AbilityTreeNode for WardKeywordAbility
impl AbilityTreeNode for WardKeywordAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for WardKeywordAbility
impl Clone for WardKeywordAbility
Sourcefn clone(&self) -> WardKeywordAbility
fn clone(&self) -> WardKeywordAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WardKeywordAbility
impl Debug for WardKeywordAbility
Sourceimpl<'de> Deserialize<'de> for WardKeywordAbility
impl<'de> Deserialize<'de> for WardKeywordAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for WardKeywordAbility
Available on crate feature parser only.
impl DummyInit for WardKeywordAbility
Available on crate feature
parser only.fn dummy_init() -> WardKeywordAbility
Sourceimpl Idris for WardKeywordAbility
impl Idris for WardKeywordAbility
Sourceimpl PartialEq for WardKeywordAbility
impl PartialEq for WardKeywordAbility
Sourceimpl Serialize for WardKeywordAbility
impl Serialize for WardKeywordAbility
impl Eq for WardKeywordAbility
impl StructuralPartialEq for WardKeywordAbility