pub struct SpellAbility {
pub effects: HeapArrayVec<Statement, MAX_CHILDREN_PER_NODE>,
}Expand description
A spell ability.
From the comprehensive rules 113.3a: Spell abilities are abilities that are followed as instructions while an instant or sorcery spell is resolving. Any text on an instant or sorcery spell is a spell ability unless it’s an activated ability, a triggered ability, or a static ability that fits the criteria described in rule 113.6.
Spell abilities are represented as a list of statements that are all of the spell effects.
Fields
effects: HeapArrayVec<Statement, MAX_CHILDREN_PER_NODE>Trait Implementations
Sourceimpl AbilityTreeNode for SpellAbility
impl AbilityTreeNode for SpellAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for SpellAbility
impl Clone for SpellAbility
Sourcefn clone(&self) -> SpellAbility
fn clone(&self) -> SpellAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpellAbility
impl Debug for SpellAbility
Sourceimpl<'de> Deserialize<'de> for SpellAbility
impl<'de> Deserialize<'de> for SpellAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for SpellAbility
Available on crate feature parser only.
impl DummyInit for SpellAbility
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for SpellAbility
impl PartialEq for SpellAbility
Sourceimpl Serialize for SpellAbility
impl Serialize for SpellAbility
impl Eq for SpellAbility
impl StructuralPartialEq for SpellAbility