pub struct AlternativeCastingPermissions {
pub player: PlayerSpecifier,
pub object: ObjectReference,
pub from_zone: ZoneReference,
pub additional_cost: Option<Cost>,
}Expand description
An alternative casting permissions grants the right to cast a card from another zone than your hand.
For example, gravecrawler says: “You may cast this card from your graveyard”.
Fields
player: PlayerSpecifierobject: ObjectReferencefrom_zone: ZoneReferenceadditional_cost: Option<Cost>Trait Implementations
Sourceimpl AbilityTreeNode for AlternativeCastingPermissions
impl AbilityTreeNode for AlternativeCastingPermissions
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for AlternativeCastingPermissions
impl Clone for AlternativeCastingPermissions
Sourcefn clone(&self) -> AlternativeCastingPermissions
fn clone(&self) -> AlternativeCastingPermissions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AlternativeCastingPermissions
impl<'de> Deserialize<'de> for AlternativeCastingPermissions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for AlternativeCastingPermissions
Available on crate feature parser only.
impl DummyInit for AlternativeCastingPermissions
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for AlternativeCastingPermissions
impl PartialEq for AlternativeCastingPermissions
Sourcefn eq(&self, other: &AlternativeCastingPermissions) -> bool
fn eq(&self, other: &AlternativeCastingPermissions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AlternativeCastingPermissions
impl StructuralPartialEq for AlternativeCastingPermissions