pub enum ObjectCharacteristicModification {
PowerToughnessModifiers(PowerToughnessModifiers),
}Expand description
A modification to the characteristics of an object.
The characteristics are Name, mana cost, color, card type, subtype, supertype, rules text, abilities, power and toughness, loyalty, hand modifier and life modifier (the last two are for vanguard only).
See also https://mtg.fandom.com/wiki/Object
Variants
PowerToughnessModifiers(PowerToughnessModifiers)