pub struct PowerToughnessModifiersMinusMinus {
pub power_mod: Number,
pub toughness_mod: Number,
}Expand description
A -X/-X power and toughness modifier.
Fields
power_mod: Numbertoughness_mod: NumberTrait Implementations
Sourceimpl AbilityTreeNode for PowerToughnessModifiersMinusMinus
impl AbilityTreeNode for PowerToughnessModifiersMinusMinus
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for PowerToughnessModifiersMinusMinus
impl Clone for PowerToughnessModifiersMinusMinus
Sourcefn clone(&self) -> PowerToughnessModifiersMinusMinus
fn clone(&self) -> PowerToughnessModifiersMinusMinus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PowerToughnessModifiersMinusMinus
impl<'de> Deserialize<'de> for PowerToughnessModifiersMinusMinus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for PowerToughnessModifiersMinusMinus
Available on crate feature parser only.
impl DummyInit for PowerToughnessModifiersMinusMinus
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for PowerToughnessModifiersMinusMinus
impl PartialEq for PowerToughnessModifiersMinusMinus
Sourcefn eq(&self, other: &PowerToughnessModifiersMinusMinus) -> bool
fn eq(&self, other: &PowerToughnessModifiersMinusMinus) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PowerToughnessModifiersMinusMinus
impl StructuralPartialEq for PowerToughnessModifiersMinusMinus