pub struct ContinuousEffectReplacementEvent {
pub replaced_event: Event,
pub replaced_by: EventReplacement,
}Expand description
A replacement effect replaces entirely one event with another.
Fields
replaced_event: Eventreplaced_by: EventReplacementTrait Implementations
Sourceimpl AbilityTreeNode for ContinuousEffectReplacementEvent
impl AbilityTreeNode for ContinuousEffectReplacementEvent
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ContinuousEffectReplacementEvent
impl Clone for ContinuousEffectReplacementEvent
Sourcefn clone(&self) -> ContinuousEffectReplacementEvent
fn clone(&self) -> ContinuousEffectReplacementEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ContinuousEffectReplacementEvent
impl<'de> Deserialize<'de> for ContinuousEffectReplacementEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ContinuousEffectReplacementEvent
Available on crate feature parser only.
impl DummyInit for ContinuousEffectReplacementEvent
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ContinuousEffectReplacementEvent
impl PartialEq for ContinuousEffectReplacementEvent
Sourcefn eq(&self, other: &ContinuousEffectReplacementEvent) -> bool
fn eq(&self, other: &ContinuousEffectReplacementEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ContinuousEffectReplacementEvent
impl StructuralPartialEq for ContinuousEffectReplacementEvent