ContinuousEffect

Struct ContinuousEffect 

pub struct ContinuousEffect {
    pub effect: ContinuousEffectKind,
}
A continuous effect, from the comprehensive rules:

An effect that modifies characteristics of objects, modifies control of objects, or affects players or the rules of the game, for a fixed or indefinite period. See rule 611, “Continuous Effects”.

See also https://mtg.fandom.com/wiki/Continuous_effect

Fields

effect: ContinuousEffectKind