pub struct StaticAbility {
pub kind: StaticAbilityKind,
pub condition: Option<Conditional>,
}Expand description
A static ability, from the comprehensive rules:
A kind of ability. Static abilities do something all the time rather than being activated or triggered. See rule 113, “Abilities”, and rule 604, “Handling Static Abilities”.
Fields
kind: StaticAbilityKindcondition: Option<Conditional>Trait Implementations
Sourceimpl AbilityTreeNode for StaticAbility
impl AbilityTreeNode for StaticAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for StaticAbility
impl Clone for StaticAbility
Sourcefn clone(&self) -> StaticAbility
fn clone(&self) -> StaticAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StaticAbility
impl Debug for StaticAbility
Sourceimpl<'de> Deserialize<'de> for StaticAbility
impl<'de> Deserialize<'de> for StaticAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for StaticAbility
Available on crate feature parser only.
impl DummyInit for StaticAbility
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for StaticAbility
impl PartialEq for StaticAbility
Sourceimpl Serialize for StaticAbility
impl Serialize for StaticAbility
impl Eq for StaticAbility
impl StructuralPartialEq for StaticAbility