pub struct AbilityWordAbility {
pub word: AbilityWord,
pub ability: Ability,
}Expand description
A Keyword Ability.
An ability word is a word that thematically groups cards with a common functionality, but has no special meaning in the Comprehensive Rules.
Fields
word: AbilityWordability: AbilityTrait Implementations
Sourceimpl AbilityTreeNode for AbilityWordAbility
impl AbilityTreeNode for AbilityWordAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for AbilityWordAbility
impl Clone for AbilityWordAbility
Sourcefn clone(&self) -> AbilityWordAbility
fn clone(&self) -> AbilityWordAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilityWordAbility
impl Debug for AbilityWordAbility
Sourceimpl<'de> Deserialize<'de> for AbilityWordAbility
impl<'de> Deserialize<'de> for AbilityWordAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for AbilityWordAbility
Available on crate feature parser only.
impl DummyInit for AbilityWordAbility
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for AbilityWordAbility
impl PartialEq for AbilityWordAbility
Sourceimpl Serialize for AbilityWordAbility
impl Serialize for AbilityWordAbility
impl Eq for AbilityWordAbility
impl StructuralPartialEq for AbilityWordAbility