pub struct KeywordAbility {
pub keyword: ExpandedKeywordAbility,
pub ability: Ability,
}Expand description
A Keyword Ability.
From the comprehensive rules: A game term, such as “flying” or “haste,” used as shorthand for a longer ability or group of abilities. See rule 702, “Keyword Abilities.”
In the tree, keyword abilities are expanded such that they keep the keyword, but also carry the full ability expanded to its actual meaning.
Fields
keyword: ExpandedKeywordAbilityability: AbilityTrait Implementations
Sourceimpl AbilityTreeNode for KeywordAbility
impl AbilityTreeNode for KeywordAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for KeywordAbility
impl Clone for KeywordAbility
Sourcefn clone(&self) -> KeywordAbility
fn clone(&self) -> KeywordAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeywordAbility
impl Debug for KeywordAbility
Sourceimpl<'de> Deserialize<'de> for KeywordAbility
impl<'de> Deserialize<'de> for KeywordAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for KeywordAbility
Available on crate feature parser only.
impl DummyInit for KeywordAbility
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for KeywordAbility
impl PartialEq for KeywordAbility
Sourceimpl Serialize for KeywordAbility
impl Serialize for KeywordAbility
impl Eq for KeywordAbility
impl StructuralPartialEq for KeywordAbility