pub struct TriggerCondition {
pub event: Event,
pub condition: Option<Conditional>,
}Expand description
Condition for a trigger ability.
This is always an event, and can optionnaly have conditions for the event to happen.
Fields
event: Eventcondition: Option<Conditional>Trait Implementations
Sourceimpl AbilityTreeNode for TriggerCondition
impl AbilityTreeNode for TriggerCondition
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for TriggerCondition
impl Clone for TriggerCondition
Sourcefn clone(&self) -> TriggerCondition
fn clone(&self) -> TriggerCondition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TriggerCondition
impl Debug for TriggerCondition
Sourceimpl<'de> Deserialize<'de> for TriggerCondition
impl<'de> Deserialize<'de> for TriggerCondition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for TriggerCondition
Available on crate feature parser only.
impl DummyInit for TriggerCondition
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for TriggerCondition
impl PartialEq for TriggerCondition
Sourceimpl Serialize for TriggerCondition
impl Serialize for TriggerCondition
impl Eq for TriggerCondition
impl StructuralPartialEq for TriggerCondition