pub struct TriggeredAbility {
pub condition: TriggerCondition,
pub effect: SpellAbility,
}Expand description
A triggered ability is an ability that waits for an event to happen to put an effect on the stack.
From the Comprehensive Rules: A kind of ability. Triggered abilities begin with the word “when,” “whenever,” or “at.” They’re written as “[Trigger condition], [effect].” See rule 113, “Abilities,” and rule 603, “Handling Triggered Abilities.”
Fields
condition: TriggerConditioneffect: SpellAbilityTrait Implementations
Sourceimpl AbilityTreeNode for TriggeredAbility
impl AbilityTreeNode for TriggeredAbility
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for TriggeredAbility
impl Clone for TriggeredAbility
Sourcefn clone(&self) -> TriggeredAbility
fn clone(&self) -> TriggeredAbility
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TriggeredAbility
impl Debug for TriggeredAbility
Sourceimpl<'de> Deserialize<'de> for TriggeredAbility
impl<'de> Deserialize<'de> for TriggeredAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TriggeredAbility
impl PartialEq for TriggeredAbility
Sourceimpl Serialize for TriggeredAbility
impl Serialize for TriggeredAbility
impl Eq for TriggeredAbility
impl StructuralPartialEq for TriggeredAbility