pub struct TokenLayout {
pub name: String,
pub card_type: TypeLine,
pub colors: Colors,
pub abilities: AbilityTree,
}Expand description
Layout of a token
Fields
name: Stringcard_type: TypeLinecolors: Colorsabilities: AbilityTreeTrait Implementations
Sourceimpl AbilityTreeNode for TokenLayout
impl AbilityTreeNode for TokenLayout
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for TokenLayout
impl Clone for TokenLayout
Sourcefn clone(&self) -> TokenLayout
fn clone(&self) -> TokenLayout
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenLayout
impl Debug for TokenLayout
Sourceimpl<'de> Deserialize<'de> for TokenLayout
impl<'de> Deserialize<'de> for TokenLayout
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for TokenLayout
Available on crate feature parser only.
impl DummyInit for TokenLayout
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl LayoutImpl for TokenLayout
impl LayoutImpl for TokenLayout
Sourceimpl PartialEq for TokenLayout
impl PartialEq for TokenLayout
Sourceimpl Serialize for TokenLayout
impl Serialize for TokenLayout
impl Eq for TokenLayout
impl StructuralPartialEq for TokenLayout