pub enum Conditional {
If(ConditionalIf),
Unless(ConditionalUnless),
}Expand description
A conditional clause allows ability to only trigger or happen when some other conditions are met.
There are two kind of contional, an “if” that requires that a condition is met, and an “unless” that requires that the condition has not been met.
Variants
If(ConditionalIf)
Unless(ConditionalUnless)