pub enum Cost {
ManaCost(ManaCost),
Imperative(Imperative),
}Expand description
A cost is something that need to be paid.
It may be a mana cost (paying mana), or any imperative that requires the player to do something (discard a card, sacrifice a creature…)
Variants
ManaCost(ManaCost)
Imperative(Imperative)