NodeKind

Enum NodeKind 

pub enum NodeKind {
Show 123 variants _EmptyNode, _NoneNode, Ability, AbilityKind, AbilityTree, AbilityWordAbility, ActivatedAbility, CastSpecifier, CharacteristicDefiningAbility, ChooseImperative, Colors, Condition, Conditional, ConditionalIf, ConditionalUnless, ConditionalImperative, ContinuousEffect, ContinuousEffectKind, ContinuousEffectModifyObject, ContinuousEffectReplacementEvent, ControlSpecifier, Cost, CostModification, CostModificationCostMore, CostModificationCostLess, CostModificationCostSet, CostModificationEffect, CounterKind, CounterOnPermanent, CounterOnPermanentReplacement, CountSpecifierIdMarker, CountSpecifier(CountSpecifier), CreateTokensEvent, CreatureAction, CreatureActionEvent, CreatureAttacksAction, CreatureDiesAction, CreatureDealsCombatDamageAction, DamagesDealt, DealsDamageImperative, DestroyImperative, EffectEventSource, EntersTheBattlefieldEvent, Event, EventReplacement, EventSource, EventSourceReferenceIdMarker, EventSourceReference(EventSourceReference), ExileImperative, ExileFollowUp, ExileFollowUpReturn, ExpandedKeywordAbilityIdMarker, ExpandedKeywordAbility(StandaloneKeywordAbility), ConditionEventOccured, ConditionObjectMatchSpecifier, GainLifeImperative, GenerateContinuousEffectImperative, Imperative, ImperativeList, ImperativeChoices, KeywordAbilityIdMarker, KeywordAbility(KeywordAbilityNodeKind), LifeGainedEvent, ManaCost, MayAbility, MtgData(MtgDataNodeKind), NumberIdMarker, NumberOfResolutions(NumberOfResolutions), NumberOfResolutionsIdMarker, Number(Number), ObjectAbilitiesModification, ObjectCharacteristicModification, ObjectGainAbility, ObjectReference, ObjectSpecifier, ObjectSpecifiers, OwnedZone, PlayerAction, PlayerActionEvent, PlayerAttacksAction, PlayerCastsSpellEvent, PlayerEventSource, PlayerSpecifier(PlayerSpecifier), PlayerSpecifierIdMarker, PlayerSpecifierObjectController, PlayerSpecifierObjectOwner, PowerToughnessModifiers, PowerToughnessModifiersMinusMinus, PowerToughnessModifiersMinusPlus, PowerToughnessModifiersPlusMinus, PowerToughnessModifiersPlusPlus, PowerToughnessModifiersSet, PreviouslyMentionnedCounter, PreviouslyMentionnedObject, PreviouslyMentionnedToken, PutCounterOnPermanentEvent, PutCountersImperative, RemovableCounterKind, RemovableCounterOnPermanent, ReplacableImperatives, ReplacedTokenKind, ReturnImperative, SacrificeImperative, SpecifiedObject, SpecifierAndList, SpecifierOrList, SpecifierOrOfAndList, SpellAbility, Statement, StaticAbility, StaticAbilityKind, Terminal(TerminalNodeKind), ThisIsYourTurn, TokenCreation, TokenCreationReplacement, TokenLayout, TriggerCondition, TriggeredAbility, TypeLineIdMarker, TypeLine(TypeLineNodeKind), UnlessConditional, ZoneReferenceIdMarker, ZoneReference(ZoneReference),
}
This enum lists all the possible nodes of the ability tree.

The goal of this enum is to distribute an unique identifier to all node kinds. The [idris_derive::Idris] implements the idris::Idris trait for this enum, providing a unique id for each variant, allowing to get that variant through this enum.

The id is distributed recursively to all variants that are unnamed with a single field.

Sometimes, it is desired to have an id for an enum node, but we also want to distribute ids to all variants of this node, since its the kind of node that carries enum only.

To do this, we create two variants, an IdMarker variant to give the node an id, and a variant that use the idris derive to recusrively add the nodes to all child variants.

Variants



_EmptyNode

A special “no node” kind.

It’s sometimes usefull to put “blank spaces” nodes when providing children. Check the crate::ability_tree::AbilityTreeNode::children implementation of the crate::ability_tree::object::SpecifierOrOfAndList for an example.

The node is placed first so that idris will give him the symbolic id 0.



_NoneNode

The none node is another speical case of node, that does not mean that there is no node, but rather that there could have been something, but instead the none variant is present.



Ability



AbilityKind



AbilityTree



AbilityWordAbility



ActivatedAbility



CastSpecifier



CharacteristicDefiningAbility



ChooseImperative



Colors



Condition



Conditional



ConditionalIf



ConditionalUnless



ConditionalImperative



ContinuousEffect



ContinuousEffectKind



ContinuousEffectModifyObject



ContinuousEffectReplacementEvent



ControlSpecifier



Cost



CostModification



CostModificationCostMore



CostModificationCostLess



CostModificationCostSet



CostModificationEffect



CounterKind



CounterOnPermanent



CounterOnPermanentReplacement



CountSpecifierIdMarker



CountSpecifier(CountSpecifier)



CreateTokensEvent



CreatureAction



CreatureActionEvent



CreatureAttacksAction



CreatureDiesAction



CreatureDealsCombatDamageAction



DamagesDealt



DealsDamageImperative



DestroyImperative



EffectEventSource



EntersTheBattlefieldEvent



Event



EventReplacement



EventSource



EventSourceReferenceIdMarker



EventSourceReference(EventSourceReference)



ExileImperative



ExileFollowUp



ExileFollowUpReturn



ExpandedKeywordAbilityIdMarker



ExpandedKeywordAbility(StandaloneKeywordAbility)



ConditionEventOccured



ConditionObjectMatchSpecifier



GainLifeImperative



GenerateContinuousEffectImperative



Imperative



ImperativeList



ImperativeChoices



KeywordAbilityIdMarker



KeywordAbility(KeywordAbilityNodeKind)



LifeGainedEvent



ManaCost



MayAbility



MtgData(MtgDataNodeKind)



NumberIdMarker



NumberOfResolutions(NumberOfResolutions)



NumberOfResolutionsIdMarker



Number(Number)



ObjectAbilitiesModification



ObjectCharacteristicModification



ObjectGainAbility



ObjectReference



ObjectSpecifier



ObjectSpecifiers



OwnedZone



PlayerAction



PlayerActionEvent



PlayerAttacksAction



PlayerCastsSpellEvent



PlayerEventSource



PlayerSpecifier(PlayerSpecifier)



PlayerSpecifierIdMarker



PlayerSpecifierObjectController



PlayerSpecifierObjectOwner



PowerToughnessModifiers



PowerToughnessModifiersMinusMinus



PowerToughnessModifiersMinusPlus



PowerToughnessModifiersPlusMinus



PowerToughnessModifiersPlusPlus



PowerToughnessModifiersSet



PreviouslyMentionnedCounter



PreviouslyMentionnedObject



PreviouslyMentionnedToken



PutCounterOnPermanentEvent



PutCountersImperative



RemovableCounterKind



RemovableCounterOnPermanent



ReplacableImperatives



ReplacedTokenKind



ReturnImperative



SacrificeImperative



SpecifiedObject



SpecifierAndList



SpecifierOrList



SpecifierOrOfAndList



SpellAbility



Statement



StaticAbility



StaticAbilityKind



Terminal(TerminalNodeKind)



ThisIsYourTurn



TokenCreation



TokenCreationReplacement



TokenLayout



TriggerCondition



TriggeredAbility



TypeLineIdMarker



TypeLine(TypeLineNodeKind)



UnlessConditional



ZoneReferenceIdMarker



ZoneReference(ZoneReference)