pub enum Event {
CreateTokens(CreateTokensEvent),
CreatureAction(CreatureActionEvent),
EntersTheBattlefield(EntersTheBattlefieldEvent),
LifeGained(LifeGainedEvent),
PlayerAction(PlayerActionEvent),
PutCounterOnPermanent(PutCounterOnPermanentEvent),
}Expand description
An event is anything that happens in a Magic: The Gathering game.
From the comprehensive rules: Anything that happens in a game. See rule 700.1.
See also https://mtg.fandom.com/wiki/Event
We keep a smaller list here, that are used to parse the cards. All events here are the ones encountered in triggered abilities / replacement effects.
Variants
CreateTokens(CreateTokensEvent)
CreatureAction(CreatureActionEvent)
EntersTheBattlefield(EntersTheBattlefieldEvent)
LifeGained(LifeGainedEvent)
PlayerAction(PlayerActionEvent)
PutCounterOnPermanent(PutCounterOnPermanentEvent)