pub struct TokenCreationReplacement {
pub source_ref: EventSourceReference,
pub create_tokens: CreateTokenImperative,
}Expand description
Fixme: doc
Fields
source_ref: EventSourceReferencecreate_tokens: CreateTokenImperativeTrait Implementations
Sourceimpl AbilityTreeNode for TokenCreationReplacement
impl AbilityTreeNode for TokenCreationReplacement
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for TokenCreationReplacement
impl Clone for TokenCreationReplacement
Sourcefn clone(&self) -> TokenCreationReplacement
fn clone(&self) -> TokenCreationReplacement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenCreationReplacement
impl Debug for TokenCreationReplacement
Sourceimpl<'de> Deserialize<'de> for TokenCreationReplacement
impl<'de> Deserialize<'de> for TokenCreationReplacement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for TokenCreationReplacement
Available on crate feature parser only.
impl DummyInit for TokenCreationReplacement
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for TokenCreationReplacement
impl PartialEq for TokenCreationReplacement
Sourceimpl Serialize for TokenCreationReplacement
impl Serialize for TokenCreationReplacement
impl Eq for TokenCreationReplacement
impl StructuralPartialEq for TokenCreationReplacement