pub struct CreatureActionEvent {
pub creatures: ObjectReference,
pub action: CreatureAction,
}Expand description
Events related to creatures.
These events are grouped together, but maybe they should not ? From a human perspective, it makes it easier to classify them this way.
Creature events includes attacking, dealing damages, blocking, etc.
Fields
creatures: ObjectReferenceaction: CreatureActionTrait Implementations
Sourceimpl AbilityTreeNode for CreatureActionEvent
impl AbilityTreeNode for CreatureActionEvent
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for CreatureActionEvent
impl Clone for CreatureActionEvent
Sourcefn clone(&self) -> CreatureActionEvent
fn clone(&self) -> CreatureActionEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatureActionEvent
impl Debug for CreatureActionEvent
Sourceimpl<'de> Deserialize<'de> for CreatureActionEvent
impl<'de> Deserialize<'de> for CreatureActionEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for CreatureActionEvent
Available on crate feature parser only.
impl DummyInit for CreatureActionEvent
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for CreatureActionEvent
impl PartialEq for CreatureActionEvent
Sourceimpl Serialize for CreatureActionEvent
impl Serialize for CreatureActionEvent
impl Eq for CreatureActionEvent
impl StructuralPartialEq for CreatureActionEvent