pub struct CreatureDealsCombatDamageAction {}Expand description
Action for a creature to deal combat damage.
Combat damage is the special kind of damage that creature deals when they fight each other, or when they attack a player.