pub struct PlayerAttacksAction {
pub attacked_player: Option<PlayerSpecifier>,
pub with: Option<ObjectReference>,
}Expand description
Action for a creature to deal combat damage.
Combat damage is the special kind of damage that creature deals when they fight each other, or when they attack a player.
Fields
attacked_player: Option<PlayerSpecifier>with: Option<ObjectReference>Trait Implementations
Sourceimpl AbilityTreeNode for PlayerAttacksAction
impl AbilityTreeNode for PlayerAttacksAction
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for PlayerAttacksAction
impl Clone for PlayerAttacksAction
Sourcefn clone(&self) -> PlayerAttacksAction
fn clone(&self) -> PlayerAttacksAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlayerAttacksAction
impl Debug for PlayerAttacksAction
Sourceimpl<'de> Deserialize<'de> for PlayerAttacksAction
impl<'de> Deserialize<'de> for PlayerAttacksAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for PlayerAttacksAction
Available on crate feature parser only.
impl DummyInit for PlayerAttacksAction
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for PlayerAttacksAction
impl PartialEq for PlayerAttacksAction
Sourceimpl Serialize for PlayerAttacksAction
impl Serialize for PlayerAttacksAction
impl Eq for PlayerAttacksAction
impl StructuralPartialEq for PlayerAttacksAction