pub struct PlayerCastsSpellEvent {
pub spell_specifiers: Option<ObjectSpecifiers>,
}Expand description
Fixme: doc
Fields
spell_specifiers: Option<ObjectSpecifiers>Trait Implementations
Sourceimpl AbilityTreeNode for PlayerCastsSpellEvent
impl AbilityTreeNode for PlayerCastsSpellEvent
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for PlayerCastsSpellEvent
impl Clone for PlayerCastsSpellEvent
Sourcefn clone(&self) -> PlayerCastsSpellEvent
fn clone(&self) -> PlayerCastsSpellEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlayerCastsSpellEvent
impl Debug for PlayerCastsSpellEvent
Sourceimpl<'de> Deserialize<'de> for PlayerCastsSpellEvent
impl<'de> Deserialize<'de> for PlayerCastsSpellEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for PlayerCastsSpellEvent
Available on crate feature parser only.
impl DummyInit for PlayerCastsSpellEvent
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for PlayerCastsSpellEvent
impl PartialEq for PlayerCastsSpellEvent
Sourceimpl Serialize for PlayerCastsSpellEvent
impl Serialize for PlayerCastsSpellEvent
impl Eq for PlayerCastsSpellEvent
impl StructuralPartialEq for PlayerCastsSpellEvent