pub struct PutCounterOnPermanentEvent {
pub source: EventSource,
pub quantity: Number,
pub on_permanent: ObjectReference,
pub counter_kind: Option<Counter>,
}Expand description
Fixme: doc
Fields
source: EventSourcequantity: Numberon_permanent: ObjectReferencecounter_kind: Option<Counter>Trait Implementations
Sourceimpl AbilityTreeNode for PutCounterOnPermanentEvent
impl AbilityTreeNode for PutCounterOnPermanentEvent
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for PutCounterOnPermanentEvent
impl Clone for PutCounterOnPermanentEvent
Sourcefn clone(&self) -> PutCounterOnPermanentEvent
fn clone(&self) -> PutCounterOnPermanentEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PutCounterOnPermanentEvent
impl Debug for PutCounterOnPermanentEvent
Sourceimpl<'de> Deserialize<'de> for PutCounterOnPermanentEvent
impl<'de> Deserialize<'de> for PutCounterOnPermanentEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for PutCounterOnPermanentEvent
Available on crate feature parser only.
impl DummyInit for PutCounterOnPermanentEvent
Available on crate feature
parser only.fn dummy_init() -> Self
impl Eq for PutCounterOnPermanentEvent
impl StructuralPartialEq for PutCounterOnPermanentEvent