pub enum CreatedTokenKind {
PreviouslyMentionnedToken {},
NewToken(TokenLayout),
}Expand description
The kind of token that we shall create with a token creation imperative.
This will either be a given token kind, e.g. “create a 2/2 red warrior token” or will reference a token previously mentionned in the ability, e.g. “create twice as many of those tokens instead”.
Variants
PreviouslyMentionnedToken
NewToken(TokenLayout)