pub enum Imperative {
Show 13 variants
Choose(ChooseImperative),
CreateToken(CreateTokenImperative),
DealsDamage(DealsDamageImperative),
Destroy(DestroyImperative),
Discard(DiscardImperative),
Draw(DrawImperative),
Exile(ExileImperative),
GainLife(GainLifeImperative),
GenerateContinuousEffect(GenerateContinuousEffectImperative),
PutCounters(PutCountersImperative),
RemoveCounters(RemoveCountersImperative),
Return(ReturnImperative),
Sacrifice(SacrificeImperative),
}Expand description
An imperative is an instruction a player must follow. It represents something that shall be done, and can appear in many places: In spell / ability resolution, in costs, etc.
Imperatives regroups a lot of what “can be done” in the game: draw cards, destroy things, move cards around, etc.
Variants
Choose(ChooseImperative)
CreateToken(CreateTokenImperative)
DealsDamage(DealsDamageImperative)
Destroy(DestroyImperative)
Discard(DiscardImperative)
Draw(DrawImperative)
Exile(ExileImperative)
GainLife(GainLifeImperative)
GenerateContinuousEffect(GenerateContinuousEffectImperative)
PutCounters(PutCountersImperative)
RemoveCounters(RemoveCountersImperative)
Return(ReturnImperative)
Sacrifice(SacrificeImperative)