pub struct ChooseImperative {
pub choice_count: Number,
pub can_choose_same_mode: bool,
pub choices: HeapArrayVec<SpellAbility, MAX_CHOICES>,
}Expand description
Fixme: doc
Fields
choice_count: Numbercan_choose_same_mode: boolchoices: HeapArrayVec<SpellAbility, MAX_CHOICES>Trait Implementations
Sourceimpl AbilityTreeNode for ChooseImperative
impl AbilityTreeNode for ChooseImperative
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ChooseImperative
impl Clone for ChooseImperative
Sourcefn clone(&self) -> ChooseImperative
fn clone(&self) -> ChooseImperative
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChooseImperative
impl Debug for ChooseImperative
Sourceimpl<'de> Deserialize<'de> for ChooseImperative
impl<'de> Deserialize<'de> for ChooseImperative
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ChooseImperative
Available on crate feature parser only.
impl DummyInit for ChooseImperative
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ChooseImperative
impl PartialEq for ChooseImperative
Sourceimpl Serialize for ChooseImperative
impl Serialize for ChooseImperative
impl Eq for ChooseImperative
impl StructuralPartialEq for ChooseImperative