pub struct CreateTokenImperative {
pub tokens: HeapArrayVec<TokenCreation, MAX_CHILDREN_PER_NODE>,
}Expand description
Imperative to create tokens.
Fields
tokens: HeapArrayVec<TokenCreation, MAX_CHILDREN_PER_NODE>Trait Implementations
Sourceimpl AbilityTreeNode for CreateTokenImperative
impl AbilityTreeNode for CreateTokenImperative
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for CreateTokenImperative
impl Clone for CreateTokenImperative
Sourcefn clone(&self) -> CreateTokenImperative
fn clone(&self) -> CreateTokenImperative
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTokenImperative
impl Debug for CreateTokenImperative
Sourceimpl<'de> Deserialize<'de> for CreateTokenImperative
impl<'de> Deserialize<'de> for CreateTokenImperative
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for CreateTokenImperative
Available on crate feature parser only.
impl DummyInit for CreateTokenImperative
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for CreateTokenImperative
impl PartialEq for CreateTokenImperative
Sourceimpl Serialize for CreateTokenImperative
impl Serialize for CreateTokenImperative
impl Eq for CreateTokenImperative
impl StructuralPartialEq for CreateTokenImperative