pub struct DamagesDealt {
pub to: ObjectReference,
pub amount: Number,
}Expand description
Single damage dealing action.
This can be the same damage to multiple targets, or shared damage among targets, or anything that was mentionned in a single damage dealing action.
Fields
to: ObjectReferenceamount: NumberTrait Implementations
Sourceimpl AbilityTreeNode for DamagesDealt
impl AbilityTreeNode for DamagesDealt
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for DamagesDealt
impl Clone for DamagesDealt
Sourcefn clone(&self) -> DamagesDealt
fn clone(&self) -> DamagesDealt
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DamagesDealt
impl Debug for DamagesDealt
Sourceimpl<'de> Deserialize<'de> for DamagesDealt
impl<'de> Deserialize<'de> for DamagesDealt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for DamagesDealt
Available on crate feature parser only.
impl DummyInit for DamagesDealt
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for DamagesDealt
impl PartialEq for DamagesDealt
Sourceimpl Serialize for DamagesDealt
impl Serialize for DamagesDealt
impl Eq for DamagesDealt
impl StructuralPartialEq for DamagesDealt