pub struct DealsDamageImperative {
pub dealer: ObjectReference,
pub damages: HeapArrayVec<DamagesDealt, MAX_DAMAGES_DEALT>,
}Expand description
Imperative to deal damage to things.
The imperative can deals multiple damages to multiple targets, for instance Drakuseth, Maw of Flames states: “it deals 4 damage to any target and 3 damage to each of up to two other targets.”
Fields
dealer: ObjectReferencedamages: HeapArrayVec<DamagesDealt, MAX_DAMAGES_DEALT>Trait Implementations
Sourceimpl AbilityTreeNode for DealsDamageImperative
impl AbilityTreeNode for DealsDamageImperative
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for DealsDamageImperative
impl Clone for DealsDamageImperative
Sourcefn clone(&self) -> DealsDamageImperative
fn clone(&self) -> DealsDamageImperative
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DealsDamageImperative
impl Debug for DealsDamageImperative
Sourceimpl<'de> Deserialize<'de> for DealsDamageImperative
impl<'de> Deserialize<'de> for DealsDamageImperative
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for DealsDamageImperative
Available on crate feature parser only.
impl DummyInit for DealsDamageImperative
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for DealsDamageImperative
impl PartialEq for DealsDamageImperative
Sourceimpl Serialize for DealsDamageImperative
impl Serialize for DealsDamageImperative
impl Eq for DealsDamageImperative
impl StructuralPartialEq for DealsDamageImperative