pub struct ExileFollowUpReturn {
pub return_imperative: ReturnImperative,
pub at: Option<Instant>,
}Expand description
Follow up to return an object after exiling it.
Fields
return_imperative: ReturnImperativeat: Option<Instant>Trait Implementations
Sourceimpl AbilityTreeNode for ExileFollowUpReturn
impl AbilityTreeNode for ExileFollowUpReturn
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ExileFollowUpReturn
impl Clone for ExileFollowUpReturn
Sourcefn clone(&self) -> ExileFollowUpReturn
fn clone(&self) -> ExileFollowUpReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExileFollowUpReturn
impl Debug for ExileFollowUpReturn
Sourceimpl<'de> Deserialize<'de> for ExileFollowUpReturn
impl<'de> Deserialize<'de> for ExileFollowUpReturn
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ExileFollowUpReturn
Available on crate feature parser only.
impl DummyInit for ExileFollowUpReturn
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ExileFollowUpReturn
impl PartialEq for ExileFollowUpReturn
Sourceimpl Serialize for ExileFollowUpReturn
impl Serialize for ExileFollowUpReturn
impl Eq for ExileFollowUpReturn
impl StructuralPartialEq for ExileFollowUpReturn