pub struct ExileImperative {
pub object: ObjectReference,
pub follow_up: Option<ExileFollowUp>,
}Expand description
Fixme: doc
Fields
object: ObjectReferencefollow_up: Option<ExileFollowUp>Trait Implementations
Sourceimpl AbilityTreeNode for ExileImperative
impl AbilityTreeNode for ExileImperative
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ExileImperative
impl Clone for ExileImperative
Sourcefn clone(&self) -> ExileImperative
fn clone(&self) -> ExileImperative
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExileImperative
impl Debug for ExileImperative
Sourceimpl<'de> Deserialize<'de> for ExileImperative
impl<'de> Deserialize<'de> for ExileImperative
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ExileImperative
Available on crate feature parser only.
impl DummyInit for ExileImperative
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ExileImperative
impl PartialEq for ExileImperative
Sourceimpl Serialize for ExileImperative
impl Serialize for ExileImperative
impl Eq for ExileImperative
impl StructuralPartialEq for ExileImperative