pub struct ImperativeList {
pub executing_player: PlayerSpecifier,
pub condition: Option<Conditional>,
pub imperatives: HeapArrayVec<Imperative, MAX_CHILDREN_PER_NODE>,
}Expand description
An imperative list is a list of imperative that should be executed.
The inner item is actually a conditional imperative, since there are list that contains imperative and conditional ones. For example, Chart a Course states: “Draw two cards. Then discard a card unless you attacked this turn.”
Fields
executing_player: PlayerSpecifiercondition: Option<Conditional>imperatives: HeapArrayVec<Imperative, MAX_CHILDREN_PER_NODE>Trait Implementations
Sourceimpl AbilityTreeNode for ImperativeList
impl AbilityTreeNode for ImperativeList
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ImperativeList
impl Clone for ImperativeList
Sourcefn clone(&self) -> ImperativeList
fn clone(&self) -> ImperativeList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImperativeList
impl Debug for ImperativeList
Sourceimpl<'de> Deserialize<'de> for ImperativeList
impl<'de> Deserialize<'de> for ImperativeList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ImperativeList
Available on crate feature parser only.
impl DummyInit for ImperativeList
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ImperativeList
impl PartialEq for ImperativeList
Sourceimpl Serialize for ImperativeList
impl Serialize for ImperativeList
impl Eq for ImperativeList
impl StructuralPartialEq for ImperativeList