pub struct SacrificeImperative {
pub object: ObjectReference,
}Expand description
Fixme: doc
Fields
object: ObjectReferenceTrait Implementations
Sourceimpl AbilityTreeNode for SacrificeImperative
impl AbilityTreeNode for SacrificeImperative
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for SacrificeImperative
impl Clone for SacrificeImperative
Sourcefn clone(&self) -> SacrificeImperative
fn clone(&self) -> SacrificeImperative
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SacrificeImperative
impl Debug for SacrificeImperative
Sourceimpl<'de> Deserialize<'de> for SacrificeImperative
impl<'de> Deserialize<'de> for SacrificeImperative
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for SacrificeImperative
Available on crate feature parser only.
impl DummyInit for SacrificeImperative
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for SacrificeImperative
impl PartialEq for SacrificeImperative
Sourceimpl Serialize for SacrificeImperative
impl Serialize for SacrificeImperative
impl Eq for SacrificeImperative
impl StructuralPartialEq for SacrificeImperative