pub struct TokenCreation {
pub amount: Number,
pub token: CreatedTokenKind,
}Expand description
A kind of created token as well as an amount for this token.
This node regroups a group of created tokens, e.g. “3 1/1 red goblins”.
Fields
amount: Numbertoken: CreatedTokenKindTrait Implementations
Sourceimpl AbilityTreeNode for TokenCreation
impl AbilityTreeNode for TokenCreation
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for TokenCreation
impl Clone for TokenCreation
Sourcefn clone(&self) -> TokenCreation
fn clone(&self) -> TokenCreation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenCreation
impl Debug for TokenCreation
Sourceimpl<'de> Deserialize<'de> for TokenCreation
impl<'de> Deserialize<'de> for TokenCreation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TokenCreation
impl PartialEq for TokenCreation
Sourceimpl Serialize for TokenCreation
impl Serialize for TokenCreation
impl Eq for TokenCreation
impl StructuralPartialEq for TokenCreation