pub enum Number {
AnyNumber {},
Number(FixedNumber),
OrMore(OrMoreNumber),
ThatMany {},
UpTo(UpToNumber),
X(XNumber),
}Expand description
A number.
A number can be as simple as a literal number (e.g. “1”, “two”, “4”) or a value that references some other objects (e.g. “ward X, where X is …”).
Number can also be “any number” where the player can choose whatever, or a reference to a previosuly mentionned number in the ability.
Variants