pub struct FixedNumber {
pub number: u32,
}Expand description
A literal number in an ability, such as “1”, “two”, “10”
Fields
number: u32Trait Implementations
Sourceimpl AbilityTreeNode for FixedNumber
impl AbilityTreeNode for FixedNumber
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for FixedNumber
impl Clone for FixedNumber
Sourcefn clone(&self) -> FixedNumber
fn clone(&self) -> FixedNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FixedNumber
impl Debug for FixedNumber
Sourceimpl<'de> Deserialize<'de> for FixedNumber
impl<'de> Deserialize<'de> for FixedNumber
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for FixedNumber
Available on crate feature parser only.
impl DummyInit for FixedNumber
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl Idris for FixedNumber
impl Idris for FixedNumber
Sourceimpl PartialEq for FixedNumber
impl PartialEq for FixedNumber
Sourceimpl Serialize for FixedNumber
impl Serialize for FixedNumber
impl Eq for FixedNumber
impl StructuralPartialEq for FixedNumber