pub struct OrMoreNumber {
pub minimum: u32,
}Expand description
A number that can be anything after some minimum value: “one or more”
Fields
minimum: u32Trait Implementations
Sourceimpl AbilityTreeNode for OrMoreNumber
impl AbilityTreeNode for OrMoreNumber
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for OrMoreNumber
impl Clone for OrMoreNumber
Sourcefn clone(&self) -> OrMoreNumber
fn clone(&self) -> OrMoreNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OrMoreNumber
impl Debug for OrMoreNumber
Sourceimpl<'de> Deserialize<'de> for OrMoreNumber
impl<'de> Deserialize<'de> for OrMoreNumber
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Idris for OrMoreNumber
impl Idris for OrMoreNumber
Sourceimpl PartialEq for OrMoreNumber
impl PartialEq for OrMoreNumber
Sourceimpl Serialize for OrMoreNumber
impl Serialize for OrMoreNumber
impl Eq for OrMoreNumber
impl StructuralPartialEq for OrMoreNumber