pub struct UpToNumber {
pub maximum: u32,
}Expand description
A number that can be anything after some minimum value: “one or more”
Fields
maximum: u32Trait Implementations
Sourceimpl AbilityTreeNode for UpToNumber
impl AbilityTreeNode for UpToNumber
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for UpToNumber
impl Clone for UpToNumber
Sourcefn clone(&self) -> UpToNumber
fn clone(&self) -> UpToNumber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpToNumber
impl Debug for UpToNumber
Sourceimpl<'de> Deserialize<'de> for UpToNumber
impl<'de> Deserialize<'de> for UpToNumber
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Idris for UpToNumber
impl Idris for UpToNumber
Sourceimpl PartialEq for UpToNumber
impl PartialEq for UpToNumber
Sourceimpl Serialize for UpToNumber
impl Serialize for UpToNumber
impl Eq for UpToNumber
impl StructuralPartialEq for UpToNumber