pub enum ObjectKind {
ArtifactSubtype(ArtifactSubtype),
BattleSubtype(BattleSubtype),
Card(CardObjectKind),
CardType(CardType),
CreatureSubtype(CreatureSubtype),
EnchantmentSubtype(EnchantmentSubtype),
InstantSorcerySubtype(SpellSubtype),
LandSubtype(LandSubtype),
Permanent(PermanentObjectKind),
PlaneswalkerSubtype(PlaneswalkerSubtype),
Spell(SpellObjectKind),
Supertype(Supertype),
}Expand description
An object kind wraps up most of the supertypes, types and subtypes, as well as some grouping types, such as spell, card and permanent.
It is mostly made to be an object specifier (e.g. “destroy target creature / enchantment / permanent”).
Variants
ArtifactSubtype(ArtifactSubtype)
BattleSubtype(BattleSubtype)
Card(CardObjectKind)
CardType(CardType)
CreatureSubtype(CreatureSubtype)
EnchantmentSubtype(EnchantmentSubtype)
InstantSorcerySubtype(SpellSubtype)
LandSubtype(LandSubtype)
Permanent(PermanentObjectKind)
PlaneswalkerSubtype(PlaneswalkerSubtype)
Spell(SpellObjectKind)
Supertype(Supertype)
Implementations