pub enum ObjectReference {
SelfReferencing(SelfReferencingObject),
ObjectAttachedTo(ObjectAttachedTo),
SpecifiedObj(SpecifiedObject),
PreviouslyMentionned(PreviouslyMentionnedObject),
}Expand description
An object reference is a way to refer to one or more objects in the game.
Objects can be anything like cards, tokens, emblems, spells on the stack, etc.
Whenever an ability will refer to objects, they will almost always use object references.
Variants
SelfReferencing(SelfReferencingObject)
ObjectAttachedTo(ObjectAttachedTo)
SpecifiedObj(SpecifiedObject)
PreviouslyMentionned(PreviouslyMentionnedObject)