pub struct CastSpecifier {
pub casting_player: PlayerSpecifier,
}Expand description
A specifier for who casts a spell.
Fields
casting_player: PlayerSpecifierTrait Implementations
Sourceimpl AbilityTreeNode for CastSpecifier
impl AbilityTreeNode for CastSpecifier
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for CastSpecifier
impl Clone for CastSpecifier
Sourcefn clone(&self) -> CastSpecifier
fn clone(&self) -> CastSpecifier
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CastSpecifier
impl Debug for CastSpecifier
Sourceimpl<'de> Deserialize<'de> for CastSpecifier
impl<'de> Deserialize<'de> for CastSpecifier
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for CastSpecifier
Available on crate feature parser only.
impl DummyInit for CastSpecifier
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for CastSpecifier
impl PartialEq for CastSpecifier
Sourceimpl Serialize for CastSpecifier
impl Serialize for CastSpecifier
impl Eq for CastSpecifier
impl StructuralPartialEq for CastSpecifier