pub struct ObjectAttachedTo {}Expand description
Object reference for the object “attached” to.
This only has meaning when the ability is on a card that can be attached to objects, and this references those objects.