pub struct SpecifiedObject {
pub amount: CountSpecifier,
pub specifiers: Option<ObjectSpecifiers>,
}Expand description
Fixme: doc Fixme: could we split this into an enum, having specified objects for all object kinds ? it would require more types, but would allow for more expressivness ? Fixme: at least we should have a specifier that acts as the main component ? “red card” -> card, “creatures you control” -> you control
Fields
amount: CountSpecifierspecifiers: Option<ObjectSpecifiers>Trait Implementations
Sourceimpl AbilityTreeNode for SpecifiedObject
impl AbilityTreeNode for SpecifiedObject
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for SpecifiedObject
impl Clone for SpecifiedObject
Sourcefn clone(&self) -> SpecifiedObject
fn clone(&self) -> SpecifiedObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecifiedObject
impl Debug for SpecifiedObject
Sourceimpl<'de> Deserialize<'de> for SpecifiedObject
impl<'de> Deserialize<'de> for SpecifiedObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SpecifiedObject
impl PartialEq for SpecifiedObject
Sourceimpl Serialize for SpecifiedObject
impl Serialize for SpecifiedObject
impl Eq for SpecifiedObject
impl StructuralPartialEq for SpecifiedObject