pub struct SpecifierAndList {
pub specifiers: ArrayVec<ObjectSpecifier, MAX_CHILDREN_PER_NODE>,
}Expand description
A list of object specifiers, grouped with a logical AND.
It means that for an object to match these specifiers, it must match all of them.
Fields
specifiers: ArrayVec<ObjectSpecifier, MAX_CHILDREN_PER_NODE>Trait Implementations
Sourceimpl AbilityTreeNode for SpecifierAndList
impl AbilityTreeNode for SpecifierAndList
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for SpecifierAndList
impl Clone for SpecifierAndList
Sourcefn clone(&self) -> SpecifierAndList
fn clone(&self) -> SpecifierAndList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecifierAndList
impl Debug for SpecifierAndList
Sourceimpl<'de> Deserialize<'de> for SpecifierAndList
impl<'de> Deserialize<'de> for SpecifierAndList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for SpecifierAndList
Available on crate feature parser only.
impl DummyInit for SpecifierAndList
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for SpecifierAndList
impl PartialEq for SpecifierAndList
Sourceimpl Serialize for SpecifierAndList
impl Serialize for SpecifierAndList
impl Eq for SpecifierAndList
impl StructuralPartialEq for SpecifierAndList