pub struct SpecifierOrList {
pub specifiers: ArrayVec<ObjectSpecifier, MAX_CHILDREN_PER_NODE>,
}Expand description
A list of object specifiers, grouped with a logical OR.
It means that for an object to match these specifiers, it must match any one specifier in the list.
Fields
specifiers: ArrayVec<ObjectSpecifier, MAX_CHILDREN_PER_NODE>Implementations
Sourceimpl SpecifierOrList
impl SpecifierOrList
pub fn add_factor_specifier( &self, factor_specifier: ObjectSpecifier, ) -> SpecifierOrOfAndList