pub struct SpecifierOrOfAndList {
pub specifiers: ArrayVec<ArrayVec<ObjectSpecifier, OR_OF_AND_LIST_INNER_ARRAY_LENGTH>, OR_OF_AND_LIST_OUTER_ARRAY_LENGTH>,
}Expand description
A list of list of object specifiers, where the outer list is grouped with a logical OR, and the inner list is grouped with a logical AND.
It means that for an object to match these specifiers, it must match all the specifiers of any one of the sublists.
This is required since sometimes, there are specifiers that applies to OR lists: “basic plains or forest” means “(basic AND plains) OR (basic AND forest)”.
This structure represent properly this case.
Fields
specifiers: ArrayVec<ArrayVec<ObjectSpecifier, OR_OF_AND_LIST_INNER_ARRAY_LENGTH>, OR_OF_AND_LIST_OUTER_ARRAY_LENGTH>Trait Implementations
Sourceimpl AbilityTreeNode for SpecifierOrOfAndList
impl AbilityTreeNode for SpecifierOrOfAndList
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for SpecifierOrOfAndList
impl Clone for SpecifierOrOfAndList
Sourcefn clone(&self) -> SpecifierOrOfAndList
fn clone(&self) -> SpecifierOrOfAndList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecifierOrOfAndList
impl Debug for SpecifierOrOfAndList
Sourceimpl<'de> Deserialize<'de> for SpecifierOrOfAndList
impl<'de> Deserialize<'de> for SpecifierOrOfAndList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for SpecifierOrOfAndList
Available on crate feature parser only.
impl DummyInit for SpecifierOrOfAndList
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for SpecifierOrOfAndList
impl PartialEq for SpecifierOrOfAndList
Sourceimpl Serialize for SpecifierOrOfAndList
impl Serialize for SpecifierOrOfAndList
impl Eq for SpecifierOrOfAndList
impl StructuralPartialEq for SpecifierOrOfAndList