pub struct ReplacableImperatives {
pub first_clause: ImperativeList,
pub condition: Conditional,
pub replacing_clause: ImperativeList,
}Expand description
Replacable imperatives are a list of imperatives that can be replaced by another list if some condition is met.
They always take the form: “do X. if Y, do Z instead”.
Fields
first_clause: ImperativeListcondition: Conditionalreplacing_clause: ImperativeListTrait Implementations
Sourceimpl AbilityTreeNode for ReplacableImperatives
impl AbilityTreeNode for ReplacableImperatives
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ReplacableImperatives
impl Clone for ReplacableImperatives
Sourcefn clone(&self) -> ReplacableImperatives
fn clone(&self) -> ReplacableImperatives
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplacableImperatives
impl Debug for ReplacableImperatives
Sourceimpl<'de> Deserialize<'de> for ReplacableImperatives
impl<'de> Deserialize<'de> for ReplacableImperatives
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ReplacableImperatives
Available on crate feature parser only.
impl DummyInit for ReplacableImperatives
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ReplacableImperatives
impl PartialEq for ReplacableImperatives
Sourceimpl Serialize for ReplacableImperatives
impl Serialize for ReplacableImperatives
impl Eq for ReplacableImperatives
impl StructuralPartialEq for ReplacableImperatives