pub struct AbilityWord {
pub ability_word: AbilityWord,
}Expand description
Wrapper around the ability word.
Fields
ability_word: AbilityWordTrait Implementations
Sourceimpl AbilityTreeNode for AbilityWord
impl AbilityTreeNode for AbilityWord
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for AbilityWord
impl Clone for AbilityWord
Sourcefn clone(&self) -> AbilityWord
fn clone(&self) -> AbilityWord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilityWord
impl Debug for AbilityWord
Sourceimpl<'de> Deserialize<'de> for AbilityWord
impl<'de> Deserialize<'de> for AbilityWord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for AbilityWord
Available on crate feature parser only.
impl DummyInit for AbilityWord
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl Hash for AbilityWord
impl Hash for AbilityWord
Sourceimpl Idris for AbilityWord
impl Idris for AbilityWord
Sourceimpl IntoToken for AbilityWord
impl IntoToken for AbilityWord
fn try_from_span(span: &Span<'_>) -> Option<Self>
Sourceimpl Ord for AbilityWord
impl Ord for AbilityWord
Sourcefn cmp(&self, other: &AbilityWord) -> Ordering
fn cmp(&self, other: &AbilityWord) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AbilityWord
impl PartialEq for AbilityWord
Sourceimpl PartialOrd for AbilityWord
impl PartialOrd for AbilityWord
Sourceimpl Serialize for AbilityWord
impl Serialize for AbilityWord
impl Copy for AbilityWord
impl Eq for AbilityWord
impl StructuralPartialEq for AbilityWord