pub struct OwnedZone {
pub zone: OwnableZone,
pub owner: OwnerSpecifier,
}Expand description
A zone that is owned by a player: libraries, hands, graveyards.
Fields
zone: OwnableZoneowner: OwnerSpecifierTrait Implementations
Sourceimpl AbilityTreeNode for OwnedZone
impl AbilityTreeNode for OwnedZone
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl<'de> Deserialize<'de> for OwnedZone
impl<'de> Deserialize<'de> for OwnedZone
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for OwnedZone
Available on crate feature parser only.
impl DummyInit for OwnedZone
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl Ord for OwnedZone
impl Ord for OwnedZone
Sourceimpl PartialOrd for OwnedZone
impl PartialOrd for OwnedZone
impl Copy for OwnedZone
impl Eq for OwnedZone
impl StructuralPartialEq for OwnedZone