pub enum AmbiguousToken {
Attack {},
Counter {},
Exile {},
Gain {},
Type {},
}Expand description
Tokens that can have different meanings depending on the context.
They are regrouped under a special “ambiguous” token kind, that we always parse first. This allows us to know that they will be parsed under this token kind, and not under and ambiguous token kind.
Variants
Attack
Ambiguous between the player action and the creature action.
Counter
Counter can either be a counter that we put on a permanent, or the action to counter a spell.
Exile
Exile can either refer to the exile zone, or to the action of exiling something.
Gain
Creatures can gain abilities Players can gain life, gain control
Type
Type can be from a card Or for mana type
Implementations
Sourceimpl AmbiguousToken
impl AmbiguousToken
pub fn try_from_span(span: &Span<'_>) -> Option<Self>