ParserNode

Enum ParserNode 

pub enum ParserNode {
Show 38 variants LexerToken(Token), Ability { ability: Ability, }, AbilityTree { tree: AbilityTree, }, Condition { condition: Condition, }, ContinuousEffect { effect: ContinuousEffect, }, Colors { colors: Colors, }, Cost { cost: Cost, }, CostModification { cost_modification: CostModification, }, CostModificationEffect { cost_modification: CostModificationEffect, }, CountSpecifier { count: CountSpecifier, }, CreatedTokenKind { kind: CreatedTokenKind, }, CreatureAction { action: CreatureAction, }, CreatureSubtypeList { list: ArrayVec<CreatureSubtype, 24>, }, Event { event: Event, }, EventReplacement { replacement: EventReplacement, }, EventSource { source: EventSource, }, EventSourceReference { source: EventSourceReference, }, ExileFollowUp { follow_up: ExileFollowUp, }, Imperative { imperative: Imperative, }, ImperativeList { imperatives: ImperativeList, }, ImperativeChoices { choices: HeapArrayVec<SpellAbility, 23>, }, KeywordAbility { ability: KeywordAbility, }, ManaCost { mana_cost: ManaCost, }, Number { number: Number, }, ObjectReference { reference: ObjectReference, }, ObjectSpecifier { specifier: ObjectSpecifier, }, ObjectSpecifiers { specifiers: ObjectSpecifiers, }, Player { player: PlayerSpecifier, }, PlayerAction { action: PlayerAction, }, PreviouslyMentionnedObject { object: PreviouslyMentionnedObject, }, PutCounterKind { kind: CounterKind, }, SpellAbility { ability: SpellAbility, }, Statement { statement: Statement, }, StaticAbilityKind { kind: StaticAbilityKind, }, TokenDefinition { token: TokenLayout, }, TriggerCondition { condition: TriggerCondition, }, AbilityKind { ability: AbilityKind, }, ZoneReference { zone: ZoneReference, },
}
Since this can carry entire ability trees, we need to box the biggest variants. Otherwise, this can easily blow up the stack when attempting to store multiple of them. Current size is 112 bytes, let’s try to keep it around here ?

Variants



LexerToken(Token)



Ability

Fields

ability: Ability


AbilityTree

Fields



Condition

Fields

condition: Condition


ContinuousEffect

Fields



Colors

Fields

colors: Colors


Cost

Fields

cost: Cost


CostModification

Fields

cost_modification: CostModification


CostModificationEffect

Fields

cost_modification: CostModificationEffect


CountSpecifier

Fields



CreatedTokenKind

Fields



CreatureAction

Fields



CreatureSubtypeList

Fields



Event

Fields

event: Event


EventReplacement

Fields

replacement: EventReplacement


EventSource

Fields



EventSourceReference



ExileFollowUp

Fields

follow_up: ExileFollowUp


Imperative

Fields

imperative: Imperative


ImperativeList

Fields

imperatives: ImperativeList


ImperativeChoices

Fields



KeywordAbility

Fields



ManaCost

Fields

mana_cost: ManaCost


Number

Fields

number: Number


ObjectReference

Fields



ObjectSpecifier

Fields



ObjectSpecifiers

Fields

specifiers: ObjectSpecifiers


Player

Fields



PlayerAction

Fields



PreviouslyMentionnedObject



PutCounterKind

Fields



SpellAbility

Fields



Statement

Fields

statement: Statement


StaticAbilityKind



TokenDefinition

Fields



TriggerCondition

Fields



AbilityKind

Fields

ability: AbilityKind


ZoneReference

Fields