pub struct ContinuousEffect {
pub effect: ContinuousEffectKind,
}Expand description
A continuous effect, from the comprehensive rules:
An effect that modifies characteristics of objects, modifies control of objects, or affects players or the rules of the game, for a fixed or indefinite period. See rule 611, “Continuous Effects”.
Fields
effect: ContinuousEffectKindTrait Implementations
Sourceimpl AbilityTreeNode for ContinuousEffect
impl AbilityTreeNode for ContinuousEffect
Sourcefn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
fn children(&self) -> ArrayVec<&dyn AbilityTreeNode, MAX_CHILDREN_PER_NODE>
Get all of the nodes children, as abstract ability tree node. Read more
Sourcefn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
fn display(&self, out: &mut TreeFormatter<'_>) -> Result<()>
Display the ability tree in a human readable manner into the given output. Read more
Sourcefn node_tag(&self) -> &'static str
fn node_tag(&self) -> &'static str
The node tag is a simple one word string that indicates what kind of node it is. Read more
Sourcefn node_description(&self) -> String
fn node_description(&self) -> String
The node name is more advanced version of the tag, and can allocate memory to dynamically
changed based on the nodes internals. Read more
Sourceimpl Clone for ContinuousEffect
impl Clone for ContinuousEffect
Sourcefn clone(&self) -> ContinuousEffect
fn clone(&self) -> ContinuousEffect
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContinuousEffect
impl Debug for ContinuousEffect
Sourceimpl<'de> Deserialize<'de> for ContinuousEffect
impl<'de> Deserialize<'de> for ContinuousEffect
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DummyInit for ContinuousEffect
Available on crate feature parser only.
impl DummyInit for ContinuousEffect
Available on crate feature
parser only.fn dummy_init() -> Self
Sourceimpl PartialEq for ContinuousEffect
impl PartialEq for ContinuousEffect
Sourceimpl Serialize for ContinuousEffect
impl Serialize for ContinuousEffect
impl Eq for ContinuousEffect
impl StructuralPartialEq for ContinuousEffect