pub struct SelfReferencingObject {}Expand description
The self referencing struct is a special kind of object specifier that references the objects that carries the ability.
For instance, in the ability text “when this creature enters, …”, “this creature” is a self referencing keyword.
Prior to the Foundation (FDN) set, self referencing was done by mentionning the name of the card, either the full name or without the epiphet.
Since FDN, self referencing can be done through “this card / creature / etc”.